svine_hessian: Expected Hessian of a parametric S-vine model

View source: R/standard_errors.R

svine_hessianR Documentation

Expected Hessian of a parametric S-vine model

Description

Expected Hessian of a parametric S-vine model

Usage

svine_hessian(x, model, cores = 1)

Arguments

x

the data.

model

S-vine model (inheriting from svine_dist).

cores

number of cores to use.

Value

A k-by-k estimate of the expected Hessian, where k is the total number of model parameters. The estimate averages the per-observation Hessian contributions. Parameters are ordered as follows: marginal parameters, copula parameters of first tree, copula parameters of second tree, etc. Duplicated parameters in the copula model are omitted.

Examples

data(returns)
dat <- returns[1:100, 1:2]

# fit parametric S-vine model with Markov order 1
model <- svine(dat, p = 1, family_set = "parametric")

# Implementation of asymptotic variances
I <- cov(svine_scores(dat, model))
H <- svine_hessian(dat, model)
Hi <- solve(H)
n_eff <- nrow(dat) - model$copula$p
Hi %*% I %*% t(Hi) / n_eff

svines documentation built on Sept. 1, 2026, 1:08 a.m.