svinecop_hessian: Expected Hessian for S-vine copula models

View source: R/svinecop_methods.R

svinecop_hessianR Documentation

Expected Hessian for S-vine copula models

Description

Expected Hessian for S-vine copula models

Usage

svinecop_hessian(u, model, cores = 1)

Arguments

u

the data; should have approximately uniform margins.

model

model inheriting from class svinecop_dist.

cores

number of cores to use; if larger than one, computations are performed in parallel on cores batches.

Value

A model$npars-by-model$npars estimate of the expected Hessian, obtained by averaging the per-observation Hessian contributions. Rows and columns correspond to model parameters in the order: copula parameters of the first tree, copula parameters of the second tree, etc. Duplicated parameters in the copula model are omitted.

See Also

svinecop_scores

Examples

# load data set
data(returns)

# convert to uniform margins
u <- pseudo_obs(returns[1:100, 1:3])

# fit parametric S-vine copula model with Markov order 1
fit <- svinecop(u, p = 1, family_set = "parametric")

svinecop_loglik(u, fit)
svinecop_scores(u, fit)
svinecop_hessian(u, fit)

svines documentation built on Sept. 1, 2026, 1:08 a.m.