svinecop_scores: Log-likelihood scores for S-vine copula models

View source: R/svinecop_methods.R

svinecop_scoresR Documentation

Log-likelihood scores for S-vine copula models

Description

Log-likelihood scores for S-vine copula models

Usage

svinecop_scores(u, model, cores = 1)

Arguments

u

the data; should have approximately uniform margins.

model

model inheriting from class svinecop_dist.

cores

number of cores to use; if larger than one, computations are performed in parallel on cores batches.

Value

An n-by-k matrix containing the score vectors in its rows, where n = NROW(u) - model$p and k = model$npars. The rows correspond to the effective time points after the first p observations. The columns correspond to model parameters in the order: copula parameters of first tree, copula parameters of second tree, etc. Duplicated parameters in the copula model are omitted.

See Also

svinecop_hessian

Examples

# load data set
data(returns)  

# convert to uniform margins
u <- pseudo_obs(returns[1:100, 1:3])

# fit parametric S-vine copula model with Markov order 1
fit <- svinecop(u, p = 1, family_set = "parametric")

svinecop_loglik(u, fit)
svinecop_scores(u, fit)
svinecop_hessian(u, fit)

svines documentation built on Sept. 1, 2026, 1:08 a.m.