View source: R/svinecop_methods.R
| svinecop_scores | R Documentation |
Log-likelihood scores for S-vine copula models
svinecop_scores(u, model, cores = 1)
u |
the data; should have approximately uniform margins. |
model |
model inheriting from class svinecop_dist. |
cores |
number of cores to use; if larger than one, computations are
performed in parallel on |
An n-by-k matrix containing the score vectors in its rows,
where n = NROW(u) - model$p and k = model$npars. The rows correspond
to the effective time points after the first p observations. The
columns correspond to model parameters in the order:
copula parameters of first tree, copula parameters of
second tree, etc. Duplicated parameters in the copula model are omitted.
svinecop_hessian
# load data set
data(returns)
# convert to uniform margins
u <- pseudo_obs(returns[1:100, 1:3])
# fit parametric S-vine copula model with Markov order 1
fit <- svinecop(u, p = 1, family_set = "parametric")
svinecop_loglik(u, fit)
svinecop_scores(u, fit)
svinecop_hessian(u, fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.